# duhdoy

Sarcasm-inator

![alt text](https://github.com/sangarshanan/duhdoy/blob/master/spongebob.jpg?raw=true)


`pip install duhdoy`


```python
>>> import duhdoy
>>> duhdoy.print("I am loving every second of this")
'i aM LoViNg eVeRy sEcOnD Of tHiS'
```
